@@ -191,7 +191,7 @@ namespace Menu {
 		{"z", "Toggle totals reset for current network device"},
 		{"a", "Toggle auto scaling for the network graphs."},
 		{"y", "Toggle synced scaling mode for network graphs."},
-		{"f, /", "To enter a process filter."},
+		{"f, /", "To enter a process filter. Start with ! for regex."},
 		{"delete", "Clear any entered filter."},
 		{"c", "Toggle per-core cpu usage of processes."},
 		{"r", "Reverse sorting order in processes box."},
@@ -490,7 +490,7 @@ namespace Menu {
 				"Kelvin, 0 = absolute zero, 1 degree change",
 				"equals 1 degree change in Celsius.",
 				"",
-				"Rankine, 0 = abosulte zero, 1 degree change",
+				"Rankine, 0 = absolute zero, 1 degree change",
 				"equals 1 degree change in Fahrenheit."},
 			{"show_cpu_freq",
 				"Show CPU frequency.",
@@ -517,6 +517,12 @@ namespace Menu {
 				"May impact performance on certain cards.",
 				"",
 				"True or False."},
+			{"rsmi_measure_pcie_speeds",
+				"Measure PCIe throughput on AMD cards.",
+				"",
+				"May impact performance on certain cards.",
+				"",
+				"True or False."},
 			{"graph_symbol_gpu",
 				"Graph symbol to use for graphs in gpu box.",
 				"",
@@ -651,7 +657,7 @@ namespace Menu {
 				"",
 				"Begin line with \"exclude=\" to change to",
 				"exclude filter.",
-				"Oterwise defaults to \"most include\" filter.",
+				"Otherwise defaults to \"most include\" filter.",
 				"",
 				"Example:",
 				"\"exclude=/boot /home/user\""},
